@@ -35,7 +35,8 @@ enum delete_problem
   {
     DELETE_No_Problem = 0,
     DELETE_No_Such_Key = 1,
-    DELETE_Must_Delete_Secret_Key = 2
+    DELETE_Must_Delete_Secret_Key = 2,
+    DELETE_Ambiguous_Specification = 3
   };
 
 
@@ -55,7 +56,7 @@ _gpgme_release_delete_result (DeleteResult result)
 
 
 static void
-delete_status_handler (GpgmeCtx ctx, GpgStatusCode code, char *args)
+delete_status_handler (GpgmeCtx ctx, GpgmeStatusCode code, char *args)
 {
   if (ctx->error)
     return;
@@ -63,7 +64,7 @@ delete_status_handler (GpgmeCtx ctx, GpgStatusCode code, char *args)
 
   switch (code)
     {
-    case STATUS_EOF:
+    case GPGME_STATUS_EOF:
       switch (ctx->result.delete->problem)
 	{
 	case DELETE_No_Problem:
@@ -74,13 +75,15 @@ delete_status_handler (GpgmeCtx ctx, GpgStatusCode code, char *args)
 	case DELETE_Must_Delete_Secret_Key:
 	  ctx->error = mk_error(Conflict);
 	  break;
+	case DELETE_Ambiguous_Specification:
+	  /* XXX Need better error value.  Fall through.  */
 	default:
 	  ctx->error = mk_error(General_Error);
 	  break;
 	}
       break;
 
-    case STATUS_DELETE_PROBLEM:
+    case GPGME_STATUS_DELETE_PROBLEM:
       ctx->result.delete->problem = atoi (args);
       break;
 
