@@ -95,6 +95,7 @@ _gpgme_release_result (GpgmeCtx ctx)
   _gpgme_release_delete_result (ctx->result.delete);
   _gpgme_release_genkey_result (ctx->result.genkey);
   _gpgme_release_keylist_result (ctx->result.keylist);
+  _gpgme_release_edit_result (ctx->result.edit);
   memset (&ctx->result, 0, sizeof (ctx->result));
   _gpgme_set_op_info (ctx, NULL);
   ctx->error = 0;
@@ -174,20 +175,23 @@ gpgme_get_op_info (GpgmeCtx ctx, int reserved)
 }
 
 
-/*
- * Store the data object with the operation info in the
- * context. Caller should not use that object anymore.
- */
+/* Store the data object INFO with the operation info in the context
+   CTX.  INFO is consumed.  Subsequent calls append the data.  */
 void
 _gpgme_set_op_info (GpgmeCtx ctx, GpgmeData info)
 {
   assert (ctx);
 
-  gpgme_data_release (ctx->op_info);
-  ctx->op_info = NULL;
-
-  if (info)
+  if (!ctx->op_info)
     ctx->op_info = info;
+  else
+    {
+      char *info_mem = 0;
+      size_t info_len;
+
+      info_mem = gpgme_data_release_and_get_mem (info, &info_len);
+      _gpgme_data_append (ctx->op_info, info_mem, info_len);
+    }
 }
 
 
@@ -507,7 +511,10 @@ gpgme_get_progress_cb (GpgmeCtx ctx, GpgmeProgressCb *r_cb, void **r_cb_value)
 void
 gpgme_set_io_cbs (GpgmeCtx ctx, struct GpgmeIOCbs *io_cbs)
 {
-  if (ctx && io_cbs)
+  if (!ctx)
+    return;
+
+  if (io_cbs)
     ctx->io_cbs = *io_cbs;
   else
     {
@@ -544,9 +551,36 @@ _gpgme_op_event_cb (void *data, GpgmeEventIO type, void *type_data)
 {
   GpgmeCtx ctx = data;
 
-  if (type == GPGME_EVENT_DONE)
-    ctx->pending = 0;
+  switch (type)
+    {
+    case GPGME_EVENT_DONE:
+      ctx->pending = 0;
+      break;
 
-  if (ctx->io_cbs.add && ctx->io_cbs.event)
-    (*ctx->io_cbs.event) (ctx->io_cbs.event_priv, type, type_data);
+    case GPGME_EVENT_NEXT_KEY:
+      _gpgme_op_keylist_event_cb (data, type, type_data);
+      break;
+
+    case GPGME_EVENT_NEXT_TRUSTITEM:
+      _gpgme_op_trustlist_event_cb (data, type, type_data);
+      break;
+    }
+}
+
+void
+_gpgme_op_event_cb_user (void *data, GpgmeEventIO type, void *type_data)
+{
+  GpgmeCtx ctx = data;
+
+  if (type == GPGME_EVENT_DONE)
+    {
+      ctx->pending = 0;
+      if (ctx->io_cbs.event)
+	(*ctx->io_cbs.event) (ctx->io_cbs.event_priv, type, &ctx->error);
+    }
+  else
+    {
+      if (ctx->io_cbs.event)
+	(*ctx->io_cbs.event) (ctx->io_cbs.event_priv, type, type_data);
+    }
 }
