@@ -1,6 +1,6 @@
 /* w32-io.c - W32 API I/O functions
  *	Copyright (C) 2000 Werner Koch (dd9jn)
- *      Copyright (C) 2001 g10 Code GmbH
+ *      Copyright (C) 2001, 2002 g10 Code GmbH
  *
  * This file is part of GPGME.
  *
@@ -19,20 +19,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
-#ifdef HAVE_DOSISH_SYSTEM
-
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
 #include <errno.h>
-#include <sys/time.h>
-#include <sys/types.h>
 #include <signal.h>
 #include <fcntl.h>
+#include <sys/time.h>
+#include <sys/types.h>
 #include <windows.h>
-#include "syshdr.h"
+#include <io.h>
 
 #include "util.h"
 #include "sema.h"
@@ -899,11 +899,8 @@ _gpgme_io_spawn ( const char *path, char **argv,
     }
 
     /* Close the other ends of the pipes */
-    for (i=0; fd_parent_list[i].fd != -1; i++ ) {
-        DEBUG1 ("Closing fd %d\n", fd_parent_list[i].fd );
-        if ( !CloseHandle ( fd_to_handle (fd_parent_list[i].fd) ) )
-            DEBUG1 ("CloseHandle failed: ec=%d", (int)GetLastError());
-    }
+    for (i = 0; fd_parent_list[i].fd != -1; i++)
+      _gpgme_io_close (fd_parent_list[i].fd);
 
     DEBUG4 ("CreateProcess ready\n"
             "-   hProcess=%p  hThread=%p\n"
@@ -985,7 +982,7 @@ _gpgme_io_kill ( int pid, int hard )
  *          >0 = number of signaled fds
  */
 int
-_gpgme_io_select ( struct io_select_fd_s *fds, size_t nfds )
+_gpgme_io_select ( struct io_select_fd_s *fds, size_t nfds, int nonblock )
 {
     HANDLE waitbuf[MAXIMUM_WAIT_OBJECTS];
     int    waitidx[MAXIMUM_WAIT_OBJECTS];
@@ -1056,7 +1053,7 @@ _gpgme_io_select ( struct io_select_fd_s *fds, size_t nfds )
     if (!any) 
         return 0;
 
-    code = WaitForMultipleObjects ( nwait, waitbuf, 0, 1000);
+    code = WaitForMultipleObjects ( nwait, waitbuf, 0, nonblock ? 0 : 1000);
     if ( code >= WAIT_OBJECT_0 && code < WAIT_OBJECT_0 + nwait ) {
         /* This WFMO is a really silly function:  It does return either
          * the index of the signaled object or if 2 objects have been
@@ -1120,14 +1117,3 @@ _gpgme_io_select ( struct io_select_fd_s *fds, size_t nfds )
     
     return count;
 }
-
-#endif /*HAVE_DOSISH_SYSTEM*/
-
-
-
-
-
-
-
-
-
